@@ -3,6 +3,7 @@ from .kinect_v2 import kinect_skeleton
 from .azure_kinect import azure_skeleton
 from .vnect import vnect_skeleton
 from .ghum import ghum_skeleton
+from .h36m import h36m_skeleton
 
 from typing import List
 from collections import OrderedDict
@@ -15,6 +16,7 @@ skeleton_definitions = {
     "kinect_v2": kinect_skeleton,
     "vnect": vnect_skeleton,
     "ghum": ghum_skeleton,
+    "h36m": h36m_skeleton,
 }
 
 
